<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

function elementarypos_settings_init() {
    register_setting( 'elementarypos', 'elementary_pos_api_key' );

    add_settings_section(
        'elementarypos_section_developers',
        __( 'Elementary POS plugin settings', 'elementarypos' ), 'elementarypos_section_developers_callback',
        'elementarypos'
    );

    add_settings_field(
        'elementarypos_field_api_key',
        __( 'Elementary POS API Key', 'elementarypos' ),
        'elementarypos_field_api_key_cb',
        'elementarypos',
        'elementarypos_section_developers',
        array(
            'label_for'         => 'elementarypos_field_api_key'
        )
    );
}

add_action( 'admin_init', 'elementarypos_settings_init' );

function elementarypos_section_developers_callback( $args ) {
    ?>
    <p><a href="https://elementarypos.com"><img src="<?php echo plugins_url( 'public/images/ElementaryPOS-logo-wide.svg' , dirname(__FILE__) ) ?>" width="400px"></a></p>
    <p><img src="<?php echo plugins_url( 'public/images/elementarypos-en.png' , dirname(__FILE__) ) ?>"></p>
    <h2> How to put sales items from Elementary POS to your WordPress page</h2>
    <p>Please use <a href="https://www.wpbeginner.com/wp-tutorials/how-to-add-a-shortcode-in-wordpress/">WordPress Shortcode</a></p>
    <h3>Show all sales items</h3>
    <code>[elementarypos_items]</code>
    <h3>Show sales items from 'Drinks' category</h3>
    <code>[elementarypos_items category="Drinks"]</code>
    <h3>Show sales items from 'Drinks' category and only with color 1</h3>
    <p>Colors are from range 1-8.</p>
    <code>[elementarypos_items category="Drinks" color="1"]</code>
    <h3>Show only name and price columns</h3>
    <p>Available columns: name,price,category,note</p>
    <code>[elementarypos_items columns="name,price"]</code>
    <br>
    <br>
    <h2>Get your API key</h2>
    <p id="<?php echo esc_attr( $args['id'] ); ?>">Get your API Key from <a href="https://app.elementarypos.com" target="_blank">Elementary POS Office</a></p>
    <?php
}

function elementarypos_field_api_key_cb( $args ) {
    $setting = get_option( 'elementary_pos_api_key' );
    ?>
    <input type="text" name="elementary_pos_api_key" value="<?php echo isset( $setting ) ? esc_attr( $setting ) : ''; ?>">
    <p class="description">
        How to get API Key:
        <ul>
        <li>Go to <a href="https://app.elementarypos.com" target="_blank">Elementary POS Office</a>.</li>
        <li>Select 'Company Settings' and 'API'.</li>
        <li>Click 'Enable API' button.</li>
        <li>Copy API key here.</li>
    </ul>
    </p>
    <?php
}

/**
 * Menu page
 */
function elementarypos_options_page() {
    add_menu_page(
        'Elementary POS',
        'Elementary POS Settings',
        'manage_options',
        'elementarypos',
        'elementarypos_options_page_html'
    );
}

add_action( 'admin_menu', 'elementarypos_options_page' );


function elementarypos_options_page_html() {
    // check user capabilities
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    if ( isset( $_GET['settings-updated'] ) ) {
        // add settings saved message with the class of "updated"
        add_settings_error( 'elementarypos_messages', 'elementarypos_message', __( 'Settings Saved', 'elementarypos' ), 'updated' );
    }

    // show error/update messages
    settings_errors( 'elementarypos_messages' );
    ?>
    <div class="wrap">
        <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>
        <form action="options.php" method="post">
            <?php
            settings_fields( 'elementarypos' );
            do_settings_sections( 'elementarypos' );
            submit_button( 'Save Settings' );
            ?>
        </form>
    </div>
    <?php
}